Index: src/codec/SkSwizzler.h |
diff --git a/src/codec/SkSwizzler.h b/src/codec/SkSwizzler.h |
index 058044e420b2a46decbd3fceb0adc9543b2c3cdb..fd205880f81da3c0ee8cb579415de9488de761d5 100644 |
--- a/src/codec/SkSwizzler.h |
+++ b/src/codec/SkSwizzler.h |
@@ -178,7 +178,7 @@ private: |
// scanline decodes. |
int fX0; // Start coordinate for the src, may be different than |
// fSrcOffset if we are sampling. |
- const int fSrcWidth; // Width of the source - i.e. before any sampling. |
+ const int fSubsetWidth; // Width of the subset of the source before any sampling. |
int fDstWidth; // Width of dst, which may differ with sampling. |
int fSampleX; // step between X samples |
const int fBPP; // if bitsPerPixel % 8 == 0 |
@@ -186,7 +186,7 @@ private: |
// else |
// fBPP is bitsPerPixel |
- SkSwizzler(RowProc proc, const SkPMColor* ctable, int srcOffset, int srcWidth, int bpp); |
+ SkSwizzler(RowProc proc, const SkPMColor* ctable, int srcOffset, int subsetWidth, int bpp); |
int onSetSampleX(int) override; |